@@ -1,10 +1,13 @@
 # flake8: noqa: F401
 
-from pandas.core.arrays.sparse.accessor import SparseAccessor, SparseFrameAccessor
+from pandas.core.arrays.sparse.accessor import (
+    SparseAccessor,
+    SparseFrameAccessor,
+)
 from pandas.core.arrays.sparse.array import (
     BlockIndex,
     IntIndex,
     SparseArray,
-    _make_index,
+    make_sparse_index,
 )
 from pandas.core.arrays.sparse.dtype import SparseDtype
